@@ -5,8 +5,7 @@ import uuid
 
 import django
 from django.apps import apps
-from django.db import connection
-from django.db import connections
+from django.db import connections, DEFAULT_DB_ALIAS
 from django.db import models
 from django.db.models.fields.related import RelatedField
 from django.db.models.sql import Query
@@ -36,16 +35,15 @@ class Context(models.Model):
     metadata = PGHistoryJSONField(default=dict)
 
     @classmethod
-    def install_pgh_attach_context_func(cls):
+    def install_pgh_attach_context_func(cls, using=DEFAULT_DB_ALIAS):
         """
         Installs a custom store procedure for upserting context
         for historical events. The upsert is aware of when tracking is
         enabled in the app (i.e. using pghistory.context())
 
-        This stored procedure is automatically installed in pghistory.apps
-        after migration
+        This stored procedure is automatically installed in pghistory migration 0004.
         """
-        with connection.cursor() as cursor:
+        with connections[using].cursor() as cursor:
             cursor.execute(
                 f"""
                 CREATE OR REPLACE FUNCTION _pgh_attach_context()
@@ -582,6 +580,19 @@ class AggregateEventQuerySet(models.QuerySet):
         return qs
 
 
+class NoObjectsManager(models.Manager):
+    """
+    Django's dumpdata and other commands will not work with AggregateEvent models
+    by default because of how they aggregate multiple tables based on objects.
+
+    We use this as the default manager for aggregate events so that dumpdata
+    and other management commands still work with these models
+    """
+
+    def get_queryset(self, *args, **kwargs):
+        return models.QuerySet(self.model, using=self._db).none()
+
+
 class BaseAggregateEvent(Event):
     """
     A proxy model for aggregating events together across tables and
@@ -603,9 +614,13 @@ class BaseAggregateEvent(Event):
     )
 
     objects = AggregateEventQuerySet.as_manager()
+    no_objects = NoObjectsManager()
 
     class Meta:
         abstract = True
+        # See the docs for NoObjectsManager about why this is the default
+        # manager
+        default_manager_name = "no_objects"
 
 
 class AggregateEvent(BaseAggregateEvent):
